# Sixfab Power Python API

## Installation
```pip3 install sixfab-power-python-api```

## Usage
#### Example Codes
* [read_sensors.py](./example/read_sensors.py)
* [rtc_set.py](./example/rtc_set.py)
* [create_event.py](./example/create_event.py)
* [update_firmware.py](./example/update_firmware.py) 

## API Docs
[API Docs](https://htmlpreview.github.io/?https://github.com/sixfab/sixfab-power-python-api/blob/master/docs/index.html)